# List of Test Cases

The test cases are saved in each markdown file.

## How to build the tables in an Excel file.

1. Install [mael](https://github.com/KenjiOhtsuka/mael).

    ```bash
    $ pip install mael
    ```

2. Build test cases, then the Excel file is generated.

    ```bash
    $ mael build .
    ```
